@@ -14,22 +14,10 @@
 # Free Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 # MA  02111-1307  USA
 
-# Copyrights (C)
-# for this R-port:
-#   1999 - 2008, Diethelm Wuertz, Rmetrics Foundation, GPL
-#   Diethelm Wuertz <wuertz@itp.phys.ethz.ch>
-#   www.rmetrics.org
-# for the code accessed (or partly included) from other R-ports:
-#   see R's copyright and license files
-# for the code accessed (or partly included) from contributed R-ports
-# and other sources
-#   see Rmetrics's copyright file
-
 
 ################################################################################
 # FUNCTION:                 DESCRIPTION:
 #  description               Sets default description string
-#  .description              Deprecated, use description
 ################################################################################
 
 
@@ -51,28 +39,5 @@ function()
 }
 
 
-# ------------------------------------------------------------------------------
-
-
-.description <- 
-function()
-{
-    # Note:
-    #   # Keep it for older Rmetrics Versions
-    
-    # FUNCTION:
-    
-    # Deprecated:
-    .Deprecated("description")
-    
-    # Description String:
-    ans = description()
-    
-    # Return Value:
-    ans
-}
-    
-
-
 ################################################################################
 
